@@ -497,9 +497,8 @@ class ResourceSet(object):
             self._store.remove((self._subject._id, self._predicate, obj))
 
     def any(self):
-        objs = list(self._store.objects(self._subject._id, self._predicate))
-        if len(objs) > 0:
-            return objs[0]
+        if len(self) > 0:
+            return list(self.copy())[0]
         else:
             return None
 
